==> sherpa_client-0.10.5-py3-none-any.whl: sherpa_client/models/segment_context.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.segment import Segment
from ..types import UNSET, Unset

T = TypeVar("T", bound="SegmentContext")


@attr.s(auto_attribs=True)
class SegmentContext:
    """
    Attributes:
        size (int):
        merged (Union[Unset, Segment]):
        segments (Union[Unset, List[Segment]]):
    """

    size: int
    merged: Union[Unset, Segment] = UNSET
    segments: Union[Unset, List[Segment]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        size = self.size
        merged: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.merged, Unset):
            merged = self.merged.to_dict()

        segments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.segments, Unset):
            segments = []
            for segments_item_data in self.segments:
                segments_item = segments_item_data.to_dict()

                segments.append(segments_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "size": size,
            }
        )
        if merged is not UNSET:
            field_dict["merged"] = merged
        if segments is not UNSET:
            field_dict["segments"] = segments

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        size = d.pop("size")

        _merged = d.pop("merged", UNSET)
        merged: Union[Unset, Segment]
        if isinstance(_merged, Unset):
            merged = UNSET
        else:
            merged = Segment.from_dict(_merged)

        segments = []
        _segments = d.pop("segments", UNSET)
        for segments_item_data in _segments or []:
            segments_item = Segment.from_dict(segments_item_data)

            segments.append(segments_item)

        segment_context = cls(
            size=size,
            merged=merged,
            segments=segments,
        )

        return segment_context

==> sherpa_client-1.0.2-py3-none-any.whl: sherpa_client/models/segment_context.py <==
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.segment import Segment


T = TypeVar("T", bound="SegmentContext")


@_attrs_define
class SegmentContext:
    """
    Attributes:
        size (int):
        merged (Union[Unset, Segment]):
        segments (Union[Unset, list['Segment']]):
    """

    size: int
    merged: Union[Unset, "Segment"] = UNSET
    segments: Union[Unset, list["Segment"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        size = self.size

        merged: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.merged, Unset):
            merged = self.merged.to_dict()

        segments: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.segments, Unset):
            segments = []
            for segments_item_data in self.segments:
                segments_item = segments_item_data.to_dict()
                segments.append(segments_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "size": size,
            }
        )
        if merged is not UNSET:
            field_dict["merged"] = merged
        if segments is not UNSET:
            field_dict["segments"] = segments

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.segment import Segment

        d = dict(src_dict)
        size = d.pop("size")

        _merged = d.pop("merged", UNSET)
        merged: Union[Unset, Segment]
        if isinstance(_merged, Unset):
            merged = UNSET
        else:
            merged = Segment.from_dict(_merged)

        segments = []
        _segments = d.pop("segments", UNSET)
        for segments_item_data in _segments or []:
            segments_item = Segment.from_dict(segments_item_data)

            segments.append(segments_item)

        segment_context = cls(
            size=size,
            merged=merged,
            segments=segments,
        )

        return segment_context
